@@ -8,10 +8,12 @@ import sys
 from unittest.mock import Mock
 try:  # pragma: no cover - not measurable
     import tkinter as tk
+    from tkinter import ttk
     from tkinter import messagebox, simpledialog, filedialog
 except ImportError as err:  # pragma: no cover - not measurable
     sys.stderr.write("WARNING: {}\n".format(err))
     tk = Mock()  # pylint: disable=C0103
+    ttk = Mock()  # pylint: disable=C0103
 
 import os
 import argparse
@@ -25,11 +27,11 @@ from dtb.common import SHARED, WarningFormatter
 from dtb import settings
 
 
-class Application(tk.Frame):  # pragma: no cover - manual test, pylint: disable=R0904,R0924
+class Application(ttk.Frame):  # pragma: no cover - manual test, pylint: disable=R0904,R0924
     """Tkinter application for DropTheBeat."""
 
     def __init__(self, master=None, root=None, name=None):
-        tk.Frame.__init__(self, master)
+        ttk.Frame.__init__(self, master)
 
         # Load the root sharing directory
         self.root = root or share.find()
@@ -79,86 +81,83 @@ class Application(tk.Frame):  # pragma: no cover - manual test, pylint: disable=
     def init(self, master):  # pylint: disable=R0914
         """Initialize frames and widgets."""  # pylint: disable=C0301
 
-        # Shared settings
-
         sticky = {'sticky': tk.NSEW}
         pad = {'padx': 5, 'pady': 5}
         stickypad = dict(chain(sticky.items(), pad.items()))
 
-        # Create frames
-
-        frame_settings = tk.Frame(master)
-        frame_incoming = tk.Frame(master)
-        frame_outgoing = tk.Frame(master)
-
-        frame_div1 = tk.Frame(master, height=2, bd=1, relief=tk.SUNKEN)
-        frame_div2 = tk.Frame(master, height=2, bd=1, relief=tk.SUNKEN)
-
-        # Create widets for frames
-
-        label_downloads = tk.Label(frame_settings, text="Downloads:")
-        entry_downloads = tk.Entry(frame_settings, state='readonly', textvariable=self.path_downloads)
-        button_downlods = tk.Button(frame_settings, text="...", command=self.browse_downloads)
-
-        self.listbox_outgoing = tk.Listbox(frame_outgoing, selectmode=tk.EXTENDED)
-        button_refout = tk.Button(frame_outgoing, text="\u21BB", command=self.update)
-        button_remove = tk.Button(frame_outgoing, text="Remove Selected", command=self.do_remove)
-        button_share = tk.Button(frame_outgoing, text="Share Songs...", command=self.do_share)
-
-        self.listbox_incoming = tk.Listbox(frame_incoming, selectmode=tk.EXTENDED)
-        button_refin = tk.Button(frame_incoming, text="\u21BB", command=self.update)
-        button_ignore = tk.Button(frame_incoming, text="Ignore Selected", command=self.do_ignore)
-        button_download = tk.Button(frame_incoming, text="Download Selected", command=self.do_download)
-
-        # Specify frame resizing
-
-        frame_settings.rowconfigure(0, weight=1)
-        frame_settings.columnconfigure(0, weight=0)
-        frame_settings.columnconfigure(1, weight=1)
-        frame_settings.columnconfigure(2, weight=0)
-
-        frame_incoming.rowconfigure(0, weight=1)
-        frame_incoming.rowconfigure(1, weight=0)
-        frame_incoming.columnconfigure(0, weight=0)
-        frame_incoming.columnconfigure(1, weight=1)
-        frame_incoming.columnconfigure(2, weight=1)
-
-        frame_outgoing.rowconfigure(0, weight=1)
-        frame_outgoing.rowconfigure(1, weight=0)
-        frame_outgoing.columnconfigure(0, weight=0)
-        frame_outgoing.columnconfigure(1, weight=1)
-        frame_outgoing.columnconfigure(2, weight=1)
-
-        # Pack widgets in frames
-
-        label_downloads.grid(row=0, column=0, **pad)
-        entry_downloads.grid(row=0, column=1, **stickypad)
-        button_downlods.grid(row=0, column=2, ipadx=5, **pad)
-
-        self.listbox_outgoing.grid(row=0, column=0, columnspan=3, **stickypad)
-        button_refout.grid(row=1, column=0, sticky=tk.SW, ipadx=5, **pad)
-        button_remove.grid(row=1, column=1, sticky=tk.SW, ipadx=5, **pad)
-        button_share.grid(row=1, column=2, sticky=tk.SE, ipadx=5, **pad)
-
-        self.listbox_incoming.grid(row=0, column=0, columnspan=3, **stickypad)
-        button_refin.grid(row=1, column=0, sticky=tk.SW, ipadx=5, **pad)
-        button_ignore.grid(row=1, column=1, sticky=tk.SW, ipadx=5, **pad)
-        button_download.grid(row=1, column=2, sticky=tk.SE, ipadx=5, **pad)
-
-        # Specify master resizing
-
+        # Configure grid
         master.rowconfigure(0, weight=0)
         master.rowconfigure(2, weight=1)
         master.rowconfigure(4, weight=1)
         master.columnconfigure(0, weight=1)
 
-        # Pack frames in master
+        # Create widgets
+        def frame_settings(master):
+            """Frame for the settings."""
+            frame = ttk.Frame(master)
 
-        frame_settings.grid(row=0, **stickypad)
-        frame_div1.grid(row=1, sticky=tk.EW, padx=10)
-        frame_outgoing.grid(row=2, **stickypad)
-        frame_div2.grid(row=3, sticky=tk.EW, padx=10)
-        frame_incoming.grid(row=4, **stickypad)
+            # Configure grid
+            frame.rowconfigure(0, weight=1)
+            frame.columnconfigure(0, weight=0)
+            frame.columnconfigure(1, weight=1)
+            frame.columnconfigure(2, weight=0)
+
+            # Place widgets
+            ttk.Label(frame, text="Downloads:").grid(row=0, column=0, **pad)
+            ttk.Entry(frame, state='readonly', textvariable=self.path_downloads).grid(row=0, column=1, **stickypad)
+            ttk.Button(frame, text="...", width=0, command=self.browse_downloads).grid(row=0, column=2, ipadx=5, **pad)
+
+            return frame
+
+        def frame_incoming(master):
+            """Frame for incoming songs."""
+            frame = ttk.Frame(master)
+
+            # Configure grid
+            frame.rowconfigure(0, weight=1)
+            frame.rowconfigure(1, weight=0)
+            frame.columnconfigure(0, weight=0)
+            frame.columnconfigure(1, weight=1)
+            frame.columnconfigure(2, weight=1)
+
+            # Place widgets
+            self.listbox_incoming = tk.Listbox(frame, selectmode=tk.EXTENDED)
+            self.listbox_incoming.grid(row=0, column=0, columnspan=3, **stickypad)
+            ttk.Button(frame, text="\u21BB", width=0, command=self.update).grid(row=1, column=0, sticky=tk.SW, ipadx=5, **pad)
+            ttk.Button(frame, text="Ignore Selected", command=self.do_ignore).grid(row=1, column=1, sticky=tk.SW, ipadx=5, **pad)
+            ttk.Button(frame, text="Download Selected", command=self.do_download).grid(row=1, column=2, sticky=tk.SE, ipadx=5, **pad)
+            return frame
+
+        def frame_outgoing(master):
+            """Frame for outgoing songs."""
+            frame = ttk.Frame(master)
+
+            # Configure grid
+            frame.rowconfigure(0, weight=1)
+            frame.rowconfigure(1, weight=0)
+            frame.columnconfigure(0, weight=0)
+            frame.columnconfigure(1, weight=1)
+            frame.columnconfigure(2, weight=1)
+
+            # Place widgets
+            self.listbox_outgoing = tk.Listbox(frame, selectmode=tk.EXTENDED)
+            self.listbox_outgoing.grid(row=0, column=0, columnspan=3, **stickypad)
+            ttk.Button(frame, text="\u21BB", width=0, command=self.update).grid(row=1, column=0, sticky=tk.SW, ipadx=5, **pad)
+            ttk.Button(frame, text="Remove Selected", command=self.do_remove).grid(row=1, column=1, sticky=tk.SW, ipadx=5, **pad)
+            ttk.Button(frame, text="Share Songs...", command=self.do_share).grid(row=1, column=2, sticky=tk.SE, ipadx=5, **pad)
+
+            return frame
+
+        def separator(master):
+            """Widget to separate frames."""
+            return ttk.Separator(master)
+
+        # Place widgets
+        frame_settings(master).grid(row=0, **stickypad)
+        separator(master).grid(row=1, sticky=tk.EW, padx=10)
+        frame_outgoing(master).grid(row=2, **stickypad)
+        separator(master).grid(row=3, sticky=tk.EW, padx=10)
+        frame_incoming(master).grid(row=4, **stickypad)
 
     def browse_downloads(self):
         """Browser for a new downloads directory."""
@@ -265,7 +264,7 @@ def run(args):
     """Start the GUI."""
 
     # Exit if tkinter is not available
-    if isinstance(tk, Mock):
+    if isinstance(tk, Mock) or isinstance(ttk, Mock):
         logging.error("tkinter is not available")
         return False
 
